const path = require('path');

module.exports = {
  entry: './src/index.js',
  output: {
    filename: 'index.js',
    library: 'onc-react-ui',
    libraryTarget: 'umd',
  },
  optimization: {
    usedExports: true,
  },
  module: {
    rules: [
      {
        test: /\.(js|jsx)$/,
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader',
        },
      },
      {
        test: /\.module\.css$/, // Sadece .module.css uzantısına sahip dosyaları seç
        use: [
          'style-loader', // Stil dosyasını DOM'a enjekte etmek için kullanılır
          {
            loader: 'css-loader',
            options: {
              modules: true, // CSS Modülleri etkinleştirildi
            },
          },
        ],
      },
      {
        test: /\.css$/, // Diğer .css uzantısına sahip dosyaları seç
        use: ['style-loader', 'css-loader'], // Normal CSS dosyalarını işlemek için kullanılır
        exclude: /\.module\.css$/, // .module.css uzantısına sahip dosyaları hariç tut
      },
      {
        test: /\.svg$/,
        use: [
          {
            loader: 'svg-url-loader',
            options: {
              limit: 8192, // This sets a limit for when the file is inlined as a data URL (bytes)
            },
          },
        ],
      },
    ],
  },
  resolve: {
    extensions: ['.js', '.jsx'],
  },
  externals: {
    react: 'react',
    'react-dom': 'react-dom',
  },
};
